# coding: utf-8

"""
    Mentortools Marketplace Server

    Mentortools service for ingesting payment-provider webhooks into normalized order events

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from marketplace_server_connector.api.catalog_api import CatalogApi  # noqa: E501


class TestCatalogApi(unittest.IsolatedAsyncioTestCase):
    """CatalogApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = CatalogApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_count_products_v1_catalog_products_count_get(self) -> None:
        """Test case for count_products_v1_catalog_products_count_get

        Count the portal's marketplace products  # noqa: E501
        """
        pass

    async def test_create_account_v1_catalog_accounts_post(self) -> None:
        """Test case for create_account_v1_catalog_accounts_post

        Connect a provider account  # noqa: E501
        """
        pass

    async def test_create_product_v1_catalog_products_post(self) -> None:
        """Test case for create_product_v1_catalog_products_post

        Register a marketplace product  # noqa: E501
        """
        pass

    async def test_list_products_v1_catalog_products_get(self) -> None:
        """Test case for list_products_v1_catalog_products_get

        List the portal's marketplace products (paginated)  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mentortools Marketplace Server

    Mentortools service for ingesting payment-provider webhooks into normalized order events

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictBool
from marketplace_server_connector.models.id_out import IdOut

class WrappedResponseIdOut(BaseModel):
    """
    WrappedResponseIdOut
    """
    done: Optional[StrictBool] = True
    result: IdOut = Field(...)
    __properties = ["done", "result"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> WrappedResponseIdOut:
        """Create an instance of WrappedResponseIdOut from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of result
        if self.result:
            _dict['result'] = self.result.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> WrappedResponseIdOut:
        """Create an instance of WrappedResponseIdOut from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return WrappedResponseIdOut.parse_obj(obj)

        _obj = WrappedResponseIdOut.parse_obj({
            "done": obj.get("done") if obj.get("done") is not None else True,
            "result": IdOut.from_dict(obj.get("result")) if obj.get("result") is not None else None
        })
        return _obj





# coding: utf-8

# flake8: noqa

"""
    Mentortools Marketplace Server

    Mentortools service for ingesting payment-provider webhooks into normalized order events

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.0.0+2656171593"

# Define package exports
__all__ = [
    "AdminApi",
    "CatalogApi",
    "IpnApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "AccountIn",
    "DrainOut",
    "Flow",
    "HTTPValidationError",
    "HealthOut",
    "IdOut",
    "IpnAcceptedOut",
    "LocationInner",
    "ProductIn",
    "ProductOut",
    "Provider",
    "ValidationError",
    "WrappedResponseDrainOut",
    "WrappedResponseHealthOut",
    "WrappedResponseIdOut",
    "WrappedResponseInt",
    "WrappedResponseIpnAcceptedOut",
    "WrappedResponseListProductOut",
]

# import apis into sdk package
from marketplace_server_connector.api.admin_api import AdminApi as AdminApi
from marketplace_server_connector.api.catalog_api import CatalogApi as CatalogApi
from marketplace_server_connector.api.ipn_api import IpnApi as IpnApi

# import ApiClient
from marketplace_server_connector.api_response import ApiResponse as ApiResponse
from marketplace_server_connector.api_client import ApiClient as ApiClient
from marketplace_server_connector.configuration import Configuration as Configuration
from marketplace_server_connector.exceptions import OpenApiException as OpenApiException
from marketplace_server_connector.exceptions import ApiTypeError as ApiTypeError
from marketplace_server_connector.exceptions import ApiValueError as ApiValueError
from marketplace_server_connector.exceptions import ApiKeyError as ApiKeyError
from marketplace_server_connector.exceptions import ApiAttributeError as ApiAttributeError
from marketplace_server_connector.exceptions import ApiException as ApiException

# import models into sdk package
from marketplace_server_connector.models.account_in import AccountIn as AccountIn
from marketplace_server_connector.models.drain_out import DrainOut as DrainOut
from marketplace_server_connector.models.flow import Flow as Flow
from marketplace_server_connector.models.http_validation_error import HTTPValidationError as HTTPValidationError
from marketplace_server_connector.models.health_out import HealthOut as HealthOut
from marketplace_server_connector.models.id_out import IdOut as IdOut
from marketplace_server_connector.models.ipn_accepted_out import IpnAcceptedOut as IpnAcceptedOut
from marketplace_server_connector.models.location_inner import LocationInner as LocationInner
from marketplace_server_connector.models.product_in import ProductIn as ProductIn
from marketplace_server_connector.models.product_out import ProductOut as ProductOut
from marketplace_server_connector.models.provider import Provider as Provider
from marketplace_server_connector.models.validation_error import ValidationError as ValidationError
from marketplace_server_connector.models.wrapped_response_drain_out import WrappedResponseDrainOut as WrappedResponseDrainOut
from marketplace_server_connector.models.wrapped_response_health_out import WrappedResponseHealthOut as WrappedResponseHealthOut
from marketplace_server_connector.models.wrapped_response_id_out import WrappedResponseIdOut as WrappedResponseIdOut
from marketplace_server_connector.models.wrapped_response_int import WrappedResponseInt as WrappedResponseInt
from marketplace_server_connector.models.wrapped_response_ipn_accepted_out import WrappedResponseIpnAcceptedOut as WrappedResponseIpnAcceptedOut
from marketplace_server_connector.models.wrapped_response_list_product_out import WrappedResponseListProductOut as WrappedResponseListProductOut



# coding: utf-8

"""
    Mentortools Marketplace Server

    Mentortools service for ingesting payment-provider webhooks into normalized order events

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, Dict, Optional
from pydantic import BaseModel, Field, StrictBool, StrictInt
from marketplace_server_connector.models.flow import Flow
from marketplace_server_connector.models.provider import Provider

class AccountIn(BaseModel):
    """
    AccountIn
    """
    portal_id: Optional[StrictInt] = None
    provider: Optional[Provider] = Field(...)
    flow: Optional[Flow] = None
    credentials: Optional[Dict[str, Any]] = None
    is_active: Optional[StrictBool] = True
    __properties = ["portal_id", "provider", "flow", "credentials", "is_active"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> AccountIn:
        """Create an instance of AccountIn from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # set to None if portal_id (nullable) is None
        # and __fields_set__ contains the field
        if self.portal_id is None and "portal_id" in self.__fields_set__:
            _dict['portal_id'] = None

        # set to None if provider (nullable) is None
        # and __fields_set__ contains the field
        if self.provider is None and "provider" in self.__fields_set__:
            _dict['provider'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> AccountIn:
        """Create an instance of AccountIn from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return AccountIn.parse_obj(obj)

        _obj = AccountIn.parse_obj({
            "portal_id": obj.get("portal_id"),
            "provider": obj.get("provider"),
            "flow": obj.get("flow"),
            "credentials": obj.get("credentials"),
            "is_active": obj.get("is_active") if obj.get("is_active") is not None else True
        })
        return _obj





# coding: utf-8

"""
    Mentortools Marketplace Server

    Mentortools service for ingesting payment-provider webhooks into normalized order events

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, Dict, List, Optional
from pydantic import BaseModel, Field, StrictStr, conlist
from marketplace_server_connector.models.location_inner import LocationInner

class ValidationError(BaseModel):
    """
    ValidationError
    """
    loc: conlist(LocationInner) = Field(...)
    msg: StrictStr = Field(...)
    type: StrictStr = Field(...)
    input: Optional[Any] = None
    ctx: Optional[Dict[str, Any]] = None
    __properties = ["loc", "msg", "type", "input", "ctx"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ValidationError:
        """Create an instance of ValidationError from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in loc (list)
        _items = []
        if self.loc:
            for _item in self.loc:
                if _item:
                    _items.append(_item.to_dict())
            _dict['loc'] = _items
        # set to None if input (nullable) is None
        # and __fields_set__ contains the field
        if self.input is None and "input" in self.__fields_set__:
            _dict['input'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ValidationError:
        """Create an instance of ValidationError from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ValidationError.parse_obj(obj)

        _obj = ValidationError.parse_obj({
            "loc": [LocationInner.from_dict(_item) for _item in obj.get("loc")] if obj.get("loc") is not None else None,
            "msg": obj.get("msg"),
            "type": obj.get("type"),
            "input": obj.get("input"),
            "ctx": obj.get("ctx")
        })
        return _obj





# flake8: noqa

# import apis into api package
from marketplace_server_connector.api.admin_api import AdminApi
from marketplace_server_connector.api.catalog_api import CatalogApi
from marketplace_server_connector.api.ipn_api import IpnApi




# coding: utf-8

# flake8: noqa
"""
    Mentortools Marketplace Server

    Mentortools service for ingesting payment-provider webhooks into normalized order events

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from marketplace_server_connector.models.account_in import AccountIn
from marketplace_server_connector.models.drain_out import DrainOut
from marketplace_server_connector.models.flow import Flow
from marketplace_server_connector.models.http_validation_error import HTTPValidationError
from marketplace_server_connector.models.health_out import HealthOut
from marketplace_server_connector.models.id_out import IdOut
from marketplace_server_connector.models.ipn_accepted_out import IpnAcceptedOut
from marketplace_server_connector.models.location_inner import LocationInner
from marketplace_server_connector.models.product_in import ProductIn
from marketplace_server_connector.models.product_out import ProductOut
from marketplace_server_connector.models.provider import Provider
from marketplace_server_connector.models.validation_error import ValidationError
from marketplace_server_connector.models.wrapped_response_drain_out import WrappedResponseDrainOut
from marketplace_server_connector.models.wrapped_response_health_out import WrappedResponseHealthOut
from marketplace_server_connector.models.wrapped_response_id_out import WrappedResponseIdOut
from marketplace_server_connector.models.wrapped_response_int import WrappedResponseInt
from marketplace_server_connector.models.wrapped_response_ipn_accepted_out import WrappedResponseIpnAcceptedOut
from marketplace_server_connector.models.wrapped_response_list_product_out import WrappedResponseListProductOut
